aboutsummaryrefslogtreecommitdiff
path: root/examples/ex1_standalone_app
diff options
context:
space:
mode:
authorKeith Dart <keith.dart@gmail.com>2017-12-15 19:40:09 -0800
committerAng Li <angli@google.com>2017-12-15 19:40:09 -0800
commitaeddc8bcd123ddf6c865622464001fe0f3835b87 (patch)
tree2497bdc66fbe0df6b5990d0b71479b520eed6620 /examples/ex1_standalone_app
parentf48f37f7a4de86306cc7193d92b464fab491b67b (diff)
downloadmobly-snippet-lib-aeddc8bcd123ddf6c865622464001fe0f3835b87.tar.gz
Update gradle, dependency versions and fix lint reported issues (#80)
* Update to latest build tools. * Fix lint issues and reformat. * Add presubmit target. * Fix IDE reported issues. * Fix test runner versions in example. * Review feedback changes. * Make getPrivateInetAddress a private method.
Diffstat (limited to 'examples/ex1_standalone_app')
-rw-r--r--examples/ex1_standalone_app/build.gradle18
-rw-r--r--examples/ex1_standalone_app/src/main/AndroidManifest.xml2
2 files changed, 10 insertions, 10 deletions
diff --git a/examples/ex1_standalone_app/src/main/AndroidManifest.xml b/examples/ex1_standalone_app/src/main/AndroidManifest.xml
index e1b5cf1..90ebdea 100644
--- a/examples/ex1_standalone_app/src/main/AndroidManifest.xml
+++ b/examples/ex1_standalone_app/src/main/AndroidManifest.xml
@@ -3,7 +3,7 @@
xmlns:android="http://schemas.android.com/apk/res/android"
package="com.google.android.mobly.snippet.example1">
- <application>
+ <application android:allowBackup="false">
<!-- Required: list of all classes with @Rpc methods. -->
<meta-data
android:name="mobly-snippets"
diff --git a/examples/ex1_standalone_app/build.gradle b/examples/ex1_standalone_app/build.gradle
index 29e61b3..1825c7e 100644
--- a/examples/ex1_standalone_app/build.gradle
+++ b/examples/ex1_standalone_app/build.gradle
@@ -1,27 +1,27 @@
apply plugin: 'com.android.application'
android {
- compileSdkVersion 24
- buildToolsVersion '25.0.0'
+ compileSdkVersion 26
defaultConfig {
applicationId "com.google.android.mobly.snippet.example1"
- minSdkVersion 11
- targetSdkVersion 24
+ minSdkVersion 15
+ targetSdkVersion 22
versionCode 1
versionName "0.0.1"
}
lintOptions {
- abortOnError true
+ abortOnError false
checkAllWarnings true
warningsAsErrors true
+ disable 'HardwareIds','MissingApplicationIcon','GoogleAppIndexingWarning','InvalidPackage','OldTargetApi'
}
}
dependencies {
// The 'compile project' dep is to compile against the snippet lib source in
// this repo. For your own snippets, you'll want to use the regular
- // 'compile' dep instead:
- //compile 'com.google.android.mobly:mobly-snippet-lib:1.2.0'
- compile project(':mobly-snippet-lib')
+ // 'implementation' dep instead:
+ //implementation 'com.google.android.mobly:mobly-snippet-lib:1.3.0'
+ implementation project(':mobly-snippet-lib')
}
@@ -1,27 +1,27 @@
}
dependencies {
- // The 'compile project' dep is to compile against the snippet lib source in
+ // The 'implementation project' dep is to compile against the snippet lib source in
// this repo. For your own snippets, you'll want to use the regular